@@ -24,9 +24,7 @@ def getDict(dictionary,*keys,**kwargs):
 
 
 if __name__ == '__main__':
-	from IutyLib.coding.asserts import *
-	import sys
-	sys.path.insert(0,"../../")
+	from IutyLib.coding.unittest import *
 	a = {'a':11,'b':{"b0":112,"b1":"ascii"}}
 	i0 = getDict(a,"a")
 	assertEqual(i0,11)
